@@ -16,35 +16,22 @@
 
 ### asymmetric copulas #########################################################
 
+###  E(u,v) = C(u^{1-a}, v^{1-b}) * D(u^a, v^b)
+###  ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
+### Liebscher (2008, JMA); the special case is Khoudraji
+
 setClass("asymCopula", contains = "copula",
          representation = representation(
            copula1 = "copula",
            copula2 = "copula"
            ),
-         validity = function(object) {
-             if(object@copula1@dimension != object@copula2@dimension)
-                 return("The dimensions of the two copulas are different")
-           dim <- object@dimension
-           ## from Classes.R
-           if (dim != as.integer(dim))
-             return("dim must be integer")
-           if (dim < 2)
-             return("dim must be >= 2")
-           param <- object@parameters
-           upper <- object@param.upbnd
-           lower <- object@param.lowbnd
-           if (length(param) != length(upper))
-             return("Parameter and upper bound have non-equal length")
-           if (length(param) != length(lower))
-             return("Parameter and lower bound have non-equal length")
-           if (any(is.na(param) | param > upper | param < lower))
-             return("Parameter value out of bound")
-	   ## else return
-	   TRUE
+	 validity = function(object) {
+	     if(object@copula1@dimension != object@copula2@dimension)
+		 "The dimensions of the two copulas are different"
+	     else TRUE
 	 })
 
-
-## Liebscher (2008, JMA); the special case is Khoudraji
 gfun <- function(u, a) u^a
 igfun <- function(u, a) u^(1 / a)
 gfunDer <- function(u, a) a * u^(a - 1)
@@ -58,7 +45,7 @@ asymCopula <- function(shapes, copula1, copula2) {
              param.upbnd = c(copula1@param.upbnd, copula2@param.upbnd, 1, 1),
              copula1 = copula1,
              copula2 = copula2,
-             message = "Asymmetric Copula")
+             fullname = "Asymmetric Copula")
 }
 
 
@@ -73,7 +60,7 @@ getCopulaComps <- function(object) {
   list(shape = shape, copula1 = copula1, copula2 = copula2)
 }
 
-AfunAsymCopula <- function(copula, w) {
+AAsymCopula <- function(copula, w) {
   comps <- getCopulaComps(copula)
   copula1 <- comps$copula1; copula2 <- comps$copula2
   ## assuming copula1 and copula2 are both evCopula
@@ -83,20 +70,20 @@ AfunAsymCopula <- function(copula, w) {
   den2 <- a1 * (1 - w) + a2 * w
   t1 <- (1 - a2) * w / den1; t1 <- ifelse(is.na(t1), 1, t1)
   t2 <- a2 * w / den2; t2 <- ifelse(is.na(t2), 1, t2)
-  den1 * Afun(copula1, t1) + den2 * Afun(copula2, t2)
+  den1 * A(copula1, t1) + den2 * A(copula2, t2)
 }
 
-pasymCopula <- function(copula, u) {
+pasymCopula <- function(u, copula) {
   if(!is.matrix(u)) u <- matrix(u, ncol = 2)
   comps <- getCopulaComps(copula)
   a1 <- comps$shape[1];  a2 <- comps$shape[2]
   copula1 <- comps$copula1; copula2 <- comps$copula2
   gu1 <- cbind(gfun(u[,1], 1 - a1), gfun(u[,2], 1 - a2))
   gu2 <- cbind(gfun(u[,1], a1), gfun(u[,2], a2))
-  pcopula(copula1, gu1) * pcopula(copula2, gu2)
+  pCopula(gu1, copula1) * pCopula(gu2, copula2)
 }
 
-dasymCopula <- function(copula, u, log=FALSE, ...) {
+dasymCopula <- function(u, copula, log=FALSE, ...) {
   ## WARNING:
   ## The following derivation assumes that both components are symmetric!
   ## See dC1du and dC2du; they don't distinguish u1 or u2.
@@ -106,14 +93,14 @@ dasymCopula <- function(copula, u, log=FALSE, ...) {
   copula1 <- comps$copula1; copula2 <- comps$copula2
   gu1 <- cbind(gfun(u[,1], 1 - a1), gfun(u[,2], 1 - a2))
   gu2 <- cbind(gfun(u[,1], a1), gfun(u[,2], a2))
-  dC1du <- derCdfWrtArgs(copula1, gu1)
-  dC2du <- derCdfWrtArgs(copula2, gu2)
-  part1 <- dcopula(copula1, gu1) *
+  dC1du <- dCdu(copula1, gu1)
+  dC2du <- dCdu(copula2, gu2)
+  part1 <- dCopula(gu1, copula1) *
       gfunDer(u[,1], 1 - a1) * gfunDer(u[,2], 1 - a2) *
-          pcopula(copula2, gu2)
+          pCopula(gu2, copula2)
   part2 <- dC1du[,1] * gfunDer(u[,1], 1 - a1) * gfunDer(u[,2], a2) * dC2du[,2]
   part3 <- dC1du[,2] * gfunDer(u[,2], 1 - a2) * gfunDer(u[,1], a1) * dC2du[,1]
-  part4 <- pcopula(copula1, gu1) * dcopula(copula2, gu2) *
+  part4 <- pCopula(gu1, copula1) * dCopula(gu2, copula2) *
       gfunDer(u[,2], a2) * gfunDer(u[,1], a1)
   ## FIXME: use lsum() and similar to get much better numerical accuracy for log - case
   if(log)
@@ -121,22 +108,26 @@ dasymCopula <- function(copula, u, log=FALSE, ...) {
   else    part1 + part2 + part3 + part4
 }
 
-rasymCopula <- function(copula, n) {
+rasymCopula <- function(n, copula) {
   comps <- getCopulaComps(copula)
   a1 <- comps$shape[1];  a2 <- comps$shape[2]
   copula1 <- comps$copula1; copula2 <- comps$copula2
   ## Theorem 2.1, Lemma 2.1, Liebscher (2008, JMA)
-  u <- rcopula(copula1, n)
-  v <- rcopula(copula2, n)
+  u <- rCopula(n, copula1)
+  v <- rCopula(n, copula2)
   x <- matrix(NA, n, 2)
   x[,1] <- pmax(igfun(u[,1], 1 - a1), igfun(v[,1], a1))
   x[,2] <- pmax(igfun(u[,2], 1 - a2), igfun(v[,2], a2))
   x
 }
 
-setMethod("Afun", signature("asymCopula"), AfunAsymCopula)
+setMethod("A", signature("asymCopula"), AAsymCopula)
 
-setMethod("rcopula", signature("asymCopula"), rasymCopula)
-setMethod("pcopula", signature("asymCopula"), pasymCopula)
-setMethod("dcopula", signature("asymCopula"), dasymCopula)
+setMethod("rCopula", signature("numeric", "asymCopula"), rasymCopula)
+
+setMethod("pCopula", signature("numeric", "asymCopula"),pasymCopula)
+setMethod("pCopula", signature("matrix", "asymCopula"), pasymCopula)
+
+setMethod("dCopula", signature("numeric", "asymCopula"), dasymCopula)
+setMethod("dCopula", signature("matrix", "asymCopula"), dasymCopula)
 
